@@ -1264,7 +1264,7 @@ def compute_alpha_signal_rsilo(df=None, core_tokens=['BTC', 'ETH'], rsi_lookback
     return mod_data_df.copy()
 
 
-def compute_alpha_signal_ls_neutral(lo_df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'], moderating_factor = 0.1, lookback_window =90, pente_window = 30, me_center = 0.5, mix_lo = True, me_short = True,ls_signal_suffix = 'LS',aggregate_and_save = True,plot_subsignal_html = True,extract_subsignal_kpi = True):
+def compute_alpha_signal_dynamical_ls_neutral(lo_df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'], moderating_factor = 0.1, lookback_window =5, pente_window = 10, me_center = 0.7, mix_lo = True, me_short = True,ls_signal_suffix = 'LS',aggregate_and_save = True,plot_subsignal_html = True,extract_subsignal_kpi = True):
     import numpy as np
     import functools
     from cryptotoolbox.signal import signal_utility
@@ -1273,6 +1273,7 @@ def compute_alpha_signal_ls_neutral(lo_df=None, core_tokens=['BTC', 'ETH'], extr
     ssjs =  core_tokens + extra_tokens
     univ = '_'.join(ssjs)
     aggregated_signals_df = None
+
     for ssj in ssjs:
         current = f'univ{univ}_lookback_{lookback_window}_pente_{pente_window}_short_{me_short}_center_{me_center}.plkl'
         print('#########'+current)
@@ -1283,11 +1284,26 @@ def compute_alpha_signal_ls_neutral(lo_df=None, core_tokens=['BTC', 'ETH'], extr
         weekly_df = data_df.copy()
         weekly_df = weekly_df[weekly_df['rebalance']]
 
+        def is_growing(a_np):
+            return np.all(a_np[:-1] <= a_np[1:])
+
+        def is_decreasing(a_np):
+            return np.all(a_np[:-1] >= a_np[1:])
+
         def compute_ranked_slope(short, center, lagging_df):
+            is_growingg = is_growing(lagging_df['rolling_slope'].values)
+            is_decreasingg = is_decreasing(lagging_df['rolling_slope'].values)
+
+            if is_growingg:
+                return 1.
+            if is_decreasingg:
+                return -1.
+
             lagging_df['rolling_slope_rank'] = lagging_df['rolling_slope'].rank(pct=True)
-            if short :
+
+            if short:
                 lagging_df['rolling_slope_rank_ls'] = 2 * lagging_df['rolling_slope_rank'] - center
-                lagging_df['rolling_slope_rank_ls'] = lagging_df['rolling_slope_rank_ls'].clip(-1,1)
+                lagging_df['rolling_slope_rank_ls'] = lagging_df['rolling_slope_rank_ls'].clip(-1, 1)
             else:
                 lagging_df['rolling_slope_rank_ls'] = lagging_df['rolling_slope_rank']
 
